from typing import Final

DOMAIN: Final[str]
MANUFACTURER: Final[str]
CONF_FFMPEG_ARGUMENTS: Final[str]
DATA_COORDINATOR: Final[str]
DATA_UNDO_UPDATE_LISTENER: Final[str]
DEFAULT_FFMPEG_ARGUMENTS: Final[str]
DEFAULT_TIMEOUT: Final[int]
