from typing import Final

SUPPORT_ALARM_ARM_HOME: Final[int]
SUPPORT_ALARM_ARM_AWAY: Final[int]
SUPPORT_ALARM_ARM_NIGHT: Final[int]
SUPPORT_ALARM_TRIGGER: Final[int]
SUPPORT_ALARM_ARM_CUSTOM_BYPASS: Final[int]
SUPPORT_ALARM_ARM_VACATION: Final[int]
CONDITION_TRIGGERED: Final[str]
CONDITION_DISARMED: Final[str]
CONDITION_ARMED_HOME: Final[str]
CONDITION_ARMED_AWAY: Final[str]
CONDITION_ARMED_NIGHT: Final[str]
CONDITION_ARMED_VACATION: Final[str]
CONDITION_ARMED_CUSTOM_BYPASS: Final[str]
