from typing import Any

CONF_AUTH_ID: str
CONF_CREATE_TOKEN: str
CONF_INSTANCE: str
CONF_INSTANCE_CLIENTS: str
CONF_ON_UNLOAD: str
CONF_PRIORITY: str
CONF_ROOT_CLIENT: str
CONF_EFFECT_HIDE_LIST: str
CONF_EFFECT_SHOW_LIST: str
DEFAULT_NAME: str
DEFAULT_ORIGIN: str
DEFAULT_PRIORITY: int
DOMAIN: str
HYPERION_MANUFACTURER_NAME: str
HYPERION_MODEL_NAME: Any
HYPERION_RELEASES_URL: str
HYPERION_VERSION_WARN_CUTOFF: str
NAME_SUFFIX_HYPERION_LIGHT: str
NAME_SUFFIX_HYPERION_PRIORITY_LIGHT: str
NAME_SUFFIX_HYPERION_COMPONENT_SWITCH: str
NAME_SUFFIX_HYPERION_CAMERA: str
SIGNAL_INSTANCE_ADD: Any
SIGNAL_INSTANCE_REMOVE: Any
SIGNAL_ENTITY_REMOVE: Any
TYPE_HYPERION_CAMERA: str
TYPE_HYPERION_LIGHT: str
TYPE_HYPERION_PRIORITY_LIGHT: str
TYPE_HYPERION_COMPONENT_SWITCH_BASE: str
