from typing import Any

DOMAIN: str
PLATFORMS: Any
DATA_FRITZ: str
DEFAULT_DEVICE_NAME: str
DEFAULT_HOST: str
DEFAULT_PORT: int
DEFAULT_USERNAME: str
ERROR_AUTH_INVALID: str
ERROR_CANNOT_CONNECT: str
ERROR_UNKNOWN: str
FRITZ_SERVICES: str
SERVICE_REBOOT: str
SERVICE_RECONNECT: str
SWITCH_TYPE_DEFLECTION: str
SWITCH_TYPE_PORTFORWARD: str
SWITCH_TYPE_WIFINETWORK: str
TRACKER_SCAN_INTERVAL: int
UPTIME_DEVIATION: int
