from typing import Any

DOMAIN: str
LOGGER: Any
DATA_CLIENT: str
DATA_LISTENER: str
DATA_PROTECTION_WINDOW: str
DATA_UV: str
TYPE_CURRENT_OZONE_LEVEL: str
TYPE_CURRENT_UV_INDEX: str
TYPE_CURRENT_UV_LEVEL: str
TYPE_MAX_UV_INDEX: str
TYPE_PROTECTION_WINDOW: str
TYPE_SAFE_EXPOSURE_TIME_1: str
TYPE_SAFE_EXPOSURE_TIME_2: str
TYPE_SAFE_EXPOSURE_TIME_3: str
TYPE_SAFE_EXPOSURE_TIME_4: str
TYPE_SAFE_EXPOSURE_TIME_5: str
TYPE_SAFE_EXPOSURE_TIME_6: str
