from typing import Any

LOGGER: Any
DOMAIN: str
DATA_CLIENT: str
DEFAULT_SCAN_INTERVAL: Any
ATTR_ALARM_DURATION: str
ATTR_ALARM_VOLUME: str
ATTR_CHIME_VOLUME: str
ATTR_ENTRY_DELAY_AWAY: str
ATTR_ENTRY_DELAY_HOME: str
ATTR_EXIT_DELAY_AWAY: str
ATTR_EXIT_DELAY_HOME: str
ATTR_LIGHT: str
ATTR_VOICE_PROMPT_VOLUME: str
VOLUMES: Any
VOLUME_STRING_MAP: Any
