from typing import Any

DOMAIN: str
CONF_LOCALE: str
CONF_KAMEREON_ACCOUNT_ID: str
DEFAULT_SCAN_INTERVAL: int
PLATFORMS: Any
DEVICE_CLASS_PLUG_STATE: str
DEVICE_CLASS_CHARGE_STATE: str
DEVICE_CLASS_CHARGE_MODE: str
