from homeassistant.components.sensor import STATE_CLASS_MEASUREMENT as STATE_CLASS_MEASUREMENT, SensorEntityDescription as SensorEntityDescription
from homeassistant.const import DEVICE_CLASS_TIMESTAMP as DEVICE_CLASS_TIMESTAMP, PERCENTAGE as PERCENTAGE
from typing import Any, Final

ATTR_BELT_UNIT_REMAINING_LIFE: Final[str]
ATTR_BLACK_DRUM_COUNTER: Final[str]
ATTR_BLACK_DRUM_REMAINING_LIFE: Final[str]
ATTR_BLACK_DRUM_REMAINING_PAGES: Final[str]
ATTR_BLACK_INK_REMAINING: Final[str]
ATTR_BLACK_TONER_REMAINING: Final[str]
ATTR_BW_COUNTER: Final[str]
ATTR_COLOR_COUNTER: Final[str]
ATTR_COUNTER: Final[str]
ATTR_CYAN_DRUM_COUNTER: Final[str]
ATTR_CYAN_DRUM_REMAINING_LIFE: Final[str]
ATTR_CYAN_DRUM_REMAINING_PAGES: Final[str]
ATTR_CYAN_INK_REMAINING: Final[str]
ATTR_CYAN_TONER_REMAINING: Final[str]
ATTR_DRUM_COUNTER: Final[str]
ATTR_DRUM_REMAINING_LIFE: Final[str]
ATTR_DRUM_REMAINING_PAGES: Final[str]
ATTR_DUPLEX_COUNTER: Final[str]
ATTR_FUSER_REMAINING_LIFE: Final[str]
ATTR_LASER_REMAINING_LIFE: Final[str]
ATTR_MAGENTA_DRUM_COUNTER: Final[str]
ATTR_MAGENTA_DRUM_REMAINING_LIFE: Final[str]
ATTR_MAGENTA_DRUM_REMAINING_PAGES: Final[str]
ATTR_MAGENTA_INK_REMAINING: Final[str]
ATTR_MAGENTA_TONER_REMAINING: Final[str]
ATTR_MANUFACTURER: Final[str]
ATTR_PAGE_COUNTER: Final[str]
ATTR_PF_KIT_1_REMAINING_LIFE: Final[str]
ATTR_PF_KIT_MP_REMAINING_LIFE: Final[str]
ATTR_REMAINING_PAGES: Final[str]
ATTR_STATUS: Final[str]
ATTR_UPTIME: Final[str]
ATTR_YELLOW_DRUM_COUNTER: Final[str]
ATTR_YELLOW_DRUM_REMAINING_LIFE: Final[str]
ATTR_YELLOW_DRUM_REMAINING_PAGES: Final[str]
ATTR_YELLOW_INK_REMAINING: Final[str]
ATTR_YELLOW_TONER_REMAINING: Final[str]
DATA_CONFIG_ENTRY: Final[str]
DOMAIN: Final[str]
UNIT_PAGES: Final[str]
PRINTER_TYPES: Final[Any]
SNMP: Final[str]
ATTRS_MAP: Final[dict[str, tuple[str, str]]]
SENSOR_TYPES: Final[tuple[SensorEntityDescription, ...]]
