from homeassistant.const import TEMPERATURE as TEMPERATURE, TEMP_CELSIUS as TEMP_CELSIUS, TEMP_FAHRENHEIT as TEMP_FAHRENHEIT, TEMP_KELVIN as TEMP_KELVIN, UNIT_NOT_RECOGNIZED_TEMPLATE as UNIT_NOT_RECOGNIZED_TEMPLATE

def fahrenheit_to_celsius(fahrenheit: float, interval: bool = ...) -> float: ...
def kelvin_to_celsius(kelvin: float, interval: bool = ...) -> float: ...
def celsius_to_fahrenheit(celsius: float, interval: bool = ...) -> float: ...
def celsius_to_kelvin(celsius: float, interval: bool = ...) -> float: ...
def convert(temperature: float, from_unit: str, to_unit: str, interval: bool = ...) -> float: ...
