from homeassistant.const import DEVICE_CLASS_CURRENT as DEVICE_CLASS_CURRENT, DEVICE_CLASS_HUMIDITY as DEVICE_CLASS_HUMIDITY, DEVICE_CLASS_ILLUMINANCE as DEVICE_CLASS_ILLUMINANCE, DEVICE_CLASS_PRESSURE as DEVICE_CLASS_PRESSURE, DEVICE_CLASS_TEMPERATURE as DEVICE_CLASS_TEMPERATURE, DEVICE_CLASS_VOLTAGE as DEVICE_CLASS_VOLTAGE, ELECTRIC_CURRENT_AMPERE as ELECTRIC_CURRENT_AMPERE, ELECTRIC_POTENTIAL_VOLT as ELECTRIC_POTENTIAL_VOLT, LIGHT_LUX as LIGHT_LUX, PERCENTAGE as PERCENTAGE, PRESSURE_MBAR as PRESSURE_MBAR, TEMP_CELSIUS as TEMP_CELSIUS
from typing import Any

CONF_MOUNT_DIR: str
CONF_NAMES: str
CONF_TYPE_OWSERVER: str
CONF_TYPE_SYSBUS: str
DEFAULT_OWSERVER_HOST: str
DEFAULT_OWSERVER_PORT: int
DEFAULT_SYSBUS_MOUNT_DIR: str
DOMAIN: str
PRESSURE_CBAR: str
SENSOR_TYPE_COUNT: str
SENSOR_TYPE_CURRENT: str
SENSOR_TYPE_HUMIDITY: str
SENSOR_TYPE_ILLUMINANCE: str
SENSOR_TYPE_MOISTURE: str
SENSOR_TYPE_PRESSURE: str
SENSOR_TYPE_SENSED: str
SENSOR_TYPE_TEMPERATURE: str
SENSOR_TYPE_VOLTAGE: str
SENSOR_TYPE_WETNESS: str
SWITCH_TYPE_LATCH: str
SWITCH_TYPE_PIO: str
SENSOR_TYPES: dict[str, list[Union[str, None]]]
PLATFORMS: Any
