from homeassistant.const import STATE_OFF as STATE_OFF, STATE_ON as STATE_ON
from typing import Final

CONF_WRITE_TIMEOUT: Final[str]
DEFAULT_NAME: Final[str]
DEFAULT_TIMEOUT: Final[int]
DEFAULT_WRITE_TIMEOUT: Final[int]
ECO_MODE: Final[str]
ICON: Final[str]
INPUT_SOURCE: Final[str]
LAMP: Final[str]
LAMP_HOURS: Final[str]
MODEL: Final[str]
CMD_DICT: Final[dict[str, str]]
