from typing import Any, Final

DOMAIN: Final[str]
STORAGE_KEY: Final[str]
STORAGE_VERSION: Final[int]
ATTR_ADAPTERS: Final[str]
ATTR_CONFIGURED_ADAPTERS: Final[str]
DEFAULT_CONFIGURED_ADAPTERS: list[str]
MDNS_TARGET_IP: Final[str]
PUBLIC_TARGET_IP: Final[str]
NETWORK_CONFIG_SCHEMA: Any
