import argparse
from homeassistant.const import REQUIRED_PYTHON_VER as REQUIRED_PYTHON_VER, RESTART_EXIT_CODE as RESTART_EXIT_CODE, __version__ as __version__

def validate_python() -> None: ...
def ensure_config_path(config_dir: str) -> None: ...
def get_arguments() -> argparse.Namespace: ...
def daemonize() -> None: ...
def check_pid(pid_file: str) -> None: ...
def write_pid(pid_file: str) -> None: ...
def closefds_osx(min_fd: int, max_fd: int) -> None: ...
def cmdline() -> list[str]: ...
def try_to_restart() -> None: ...
def main() -> int: ...
