from typing import Any

DOMAIN: str
LOGGER: Any
INTEGRATION_TYPE_GEOGRAPHY_COORDS: str
INTEGRATION_TYPE_GEOGRAPHY_NAME: str
INTEGRATION_TYPE_NODE_PRO: str
CONF_CITY: str
CONF_COUNTRY: str
CONF_GEOGRAPHIES: str
CONF_INTEGRATION_TYPE: str
DATA_COORDINATOR: str
