DOMAIN: str
SIGN_ARIES: str
SIGN_TAURUS: str
SIGN_GEMINI: str
SIGN_CANCER: str
SIGN_LEO: str
SIGN_VIRGO: str
SIGN_LIBRA: str
SIGN_SCORPIO: str
SIGN_SAGITTARIUS: str
SIGN_CAPRICORN: str
SIGN_AQUARIUS: str
SIGN_PISCES: str
ELEMENT_FIRE: str
ELEMENT_AIR: str
ELEMENT_EARTH: str
ELEMENT_WATER: str
MODALITY_CARDINAL: str
MODALITY_FIXED: str
MODALITY_MUTABLE: str
ATTR_ELEMENT: str
ATTR_MODALITY: str
