from typing import Any

DOMAIN: str
ATTR_ENDPOINTS: str
ATTR_STREAMS: str
HLS_PROVIDER: str
RECORDER_PROVIDER: str
OUTPUT_FORMATS: Any
SEGMENT_CONTAINER_FORMAT: str
RECORDER_CONTAINER_FORMAT: str
AUDIO_CODECS: Any
FORMAT_CONTENT_TYPE: Any
OUTPUT_IDLE_TIMEOUT: int
NUM_PLAYLIST_SEGMENTS: int
MAX_SEGMENTS: int
TARGET_SEGMENT_DURATION: float
TARGET_PART_DURATION: float
SEGMENT_DURATION_ADJUSTER: float
MIN_SEGMENT_DURATION: Any
EXT_X_START: float
PACKETS_TO_WAIT_FOR_AUDIO: int
MAX_TIMESTAMP_GAP: int
MAX_MISSING_DTS: int
SOURCE_TIMEOUT: int
STREAM_RESTART_INCREMENT: int
STREAM_RESTART_RESET_TIME: int
