from typing import Any

API: str
DOMAIN: str
MANUFACTURER: str
DEFAULT_ATTRIBUTION: Any
PLATFORMS: Any
MODEL_NAPLUG: str
MODEL_NATHERM1: str
MODEL_NRV: str
MODEL_NOC: str
MODEL_NACAMERA: str
MODEL_NSD: str
MODEL_NACAMDOORTAG: str
MODEL_NHC: str
MODEL_NAMAIN: str
MODEL_NAMODULE1: str
MODEL_NAMODULE4: str
MODEL_NAMODULE3: str
MODEL_NAMODULE2: str
MODEL_PUBLIC: str
MODELS: Any
AUTH: str
CONF_PUBLIC: str
CAMERA_DATA: str
HOME_DATA: str
DATA_HANDLER: str
SIGNAL_NAME: str
CONF_CLOUDHOOK_URL: str
CONF_WEATHER_AREAS: str
CONF_NEW_AREA: str
CONF_AREA_NAME: str
CONF_LAT_NE: str
CONF_LON_NE: str
CONF_LAT_SW: str
CONF_LON_SW: str
CONF_PUBLIC_MODE: str
CONF_UUID: str
OAUTH2_AUTHORIZE: str
OAUTH2_TOKEN: str
DATA_CAMERAS: str
DATA_DEVICE_IDS: str
DATA_EVENTS: str
DATA_HOMES: str
DATA_PERSONS: str
DATA_SCHEDULES: str
NETATMO_WEBHOOK_URL: Any
NETATMO_EVENT: str
DEFAULT_PERSON: str
DEFAULT_DISCOVERY: bool
DEFAULT_WEBHOOKS: bool
ATTR_PSEUDO: str
ATTR_EVENT_TYPE: str
ATTR_HEATING_POWER_REQUEST: str
ATTR_HOME_ID: str
ATTR_HOME_NAME: str
ATTR_PERSON: str
ATTR_PERSONS: str
ATTR_IS_KNOWN: str
ATTR_FACE_URL: str
ATTR_SCHEDULE_ID: str
ATTR_SCHEDULE_NAME: str
ATTR_SELECTED_SCHEDULE: str
ATTR_CAMERA_LIGHT_MODE: str
SERVICE_SET_CAMERA_LIGHT: str
SERVICE_SET_SCHEDULE: str
SERVICE_SET_PERSONS_HOME: str
SERVICE_SET_PERSON_AWAY: str
EVENT_TYPE_SET_POINT: str
EVENT_TYPE_CANCEL_SET_POINT: str
EVENT_TYPE_THERM_MODE: str
EVENT_TYPE_SCHEDULE: str
EVENT_TYPE_LIGHT_MODE: str
EVENT_TYPE_CAMERA_OUTDOOR: str
EVENT_TYPE_CAMERA_ANIMAL: str
EVENT_TYPE_CAMERA_HUMAN: str
EVENT_TYPE_CAMERA_VEHICLE: str
EVENT_TYPE_CAMERA_MOVEMENT: str
EVENT_TYPE_CAMERA_PERSON: str
EVENT_TYPE_CAMERA_PERSON_AWAY: str
EVENT_TYPE_DOOR_TAG_SMALL_MOVE: str
EVENT_TYPE_DOOR_TAG_BIG_MOVE: str
EVENT_TYPE_DOOR_TAG_OPEN: str
EVENT_TYPE_OFF: str
EVENT_TYPE_ON: str
EVENT_TYPE_ALARM_STARTED: str
OUTDOOR_CAMERA_TRIGGERS: Any
INDOOR_CAMERA_TRIGGERS: Any
DOOR_TAG_TRIGGERS: Any
CLIMATE_TRIGGERS: Any
EVENT_ID_MAP: Any
MODE_LIGHT_ON: str
MODE_LIGHT_OFF: str
MODE_LIGHT_AUTO: str
CAMERA_LIGHT_MODES: Any
WEBHOOK_ACTIVATION: str
WEBHOOK_DEACTIVATION: str
WEBHOOK_NACAMERA_CONNECTION: str
WEBHOOK_PUSH_TYPE: str
WEBHOOK_LIGHT_MODE: str
