from typing import Any

CONF_ADDON_DEVICE: str
CONF_ADDON_EMULATE_HARDWARE: str
CONF_ADDON_LOG_LEVEL: str
CONF_ADDON_NETWORK_KEY: str
CONF_INTEGRATION_CREATED_ADDON: str
CONF_NETWORK_KEY: str
CONF_USB_PATH: str
CONF_USE_ADDON: str
CONF_DATA_COLLECTION_OPTED_IN: str
DOMAIN: str
DATA_CLIENT: str
DATA_PLATFORM_SETUP: str
EVENT_DEVICE_ADDED_TO_REGISTRY: Any
LOGGER: Any
ZWAVE_JS_VALUE_NOTIFICATION_EVENT: Any
ZWAVE_JS_NOTIFICATION_EVENT: Any
ZWAVE_JS_VALUE_UPDATED_EVENT: Any
ATTR_NODE_ID: str
ATTR_HOME_ID: str
ATTR_ENDPOINT: str
ATTR_LABEL: str
ATTR_VALUE: str
ATTR_VALUE_RAW: str
ATTR_COMMAND_CLASS: str
ATTR_COMMAND_CLASS_NAME: str
ATTR_TYPE: str
ATTR_PROPERTY_NAME: str
ATTR_PROPERTY_KEY_NAME: str
ATTR_PROPERTY: str
ATTR_PROPERTY_KEY: str
ATTR_PARAMETERS: str
ATTR_EVENT: str
ATTR_EVENT_LABEL: str
ATTR_EVENT_TYPE: str
ATTR_EVENT_DATA: str
ATTR_DATA_TYPE: str
ATTR_WAIT_FOR_RESULT: str
ATTR_OPTIONS: str
ATTR_NODE: str
ATTR_ZWAVE_VALUE: str
SERVICE_SET_VALUE: str
SERVICE_RESET_METER: str
SERVICE_MULTICAST_SET_VALUE: str
SERVICE_PING: str
SERVICE_REFRESH_VALUE: str
SERVICE_SET_CONFIG_PARAMETER: str
SERVICE_BULK_SET_PARTIAL_CONFIG_PARAMETERS: str
ATTR_NODES: str
ATTR_CONFIG_PARAMETER: str
ATTR_CONFIG_PARAMETER_BITMASK: str
ATTR_CONFIG_VALUE: str
ATTR_REFRESH_ALL_VALUES: str
ATTR_BROADCAST: str
ATTR_METER_TYPE: str
ADDON_SLUG: str
