from . import KNXModule as KNXModule
from .const import DOMAIN as DOMAIN
from homeassistant.helpers.entity import Entity as Entity
from typing import Any
from xknx.devices import Device as XknxDevice

class KnxEntity(Entity):
    _attr_should_poll: bool
    _device: Any
    def __init__(self, device: XknxDevice) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def available(self) -> bool: ...
    async def async_update(self) -> None: ...
    async def after_update_callback(self, device: XknxDevice) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...
