from .types import CategoryType as CategoryType, PolicyType as PolicyType

def merge_policies(policies: list[PolicyType]) -> PolicyType: ...
def _merge_policies(sources: list[CategoryType]) -> CategoryType: ...
