from typing import Any

DOMAIN: str
LOGGER: Any
DATA_COORDINATOR: str
SENSOR_BATTERY: str
SENSOR_DOOR: str
SENSOR_GARAGE_DOOR: str
SENSOR_LEAK: str
SENSOR_MISSING: str
SENSOR_SAFE: str
SENSOR_SLIDING: str
SENSOR_SMOKE_CO: str
SENSOR_TEMPERATURE: str
SENSOR_WINDOW_HINGED_HORIZONTAL: str
SENSOR_WINDOW_HINGED_VERTICAL: str
