from typing import Any, Final

ATTR_CID: Final[str]
ATTR_MAC: Final[str]
ATTR_MANUFACTURER: Final[str]
ATTR_MODEL: Final[str]
CONF_IGNORED_SOURCES: Final[str]
BRAVIA_CONFIG_FILE: Final[str]
CLIENTID_PREFIX: Final[str]
DEFAULT_NAME: Final[Any]
DOMAIN: Final[str]
NICKNAME: Final[str]
