from typing import Final

DOMAIN: Final[str]
DATA_CAMERA_PREFS: Final[str]
PREF_PRELOAD_STREAM: Final[str]
SERVICE_RECORD: Final[str]
CONF_LOOKBACK: Final[str]
CONF_DURATION: Final[str]
CAMERA_STREAM_SOURCE_TIMEOUT: Final[int]
CAMERA_IMAGE_TIMEOUT: Final[int]
