from homeassistant.const import DEGREE as DEGREE, ELECTRIC_POTENTIAL_VOLT as ELECTRIC_POTENTIAL_VOLT, PERCENTAGE as PERCENTAGE, TEMP_CELSIUS as TEMP_CELSIUS, TEMP_FAHRENHEIT as TEMP_FAHRENHEIT, TEMP_KELVIN as TEMP_KELVIN
from typing import Any

PLATFORMS: Any
DOMAIN: str
DATA_LCN: str
DEFAULT_NAME: str
CONNECTION: str
CONF_HARDWARE_SERIAL: str
CONF_SOFTWARE_SERIAL: str
CONF_HARDWARE_TYPE: str
CONF_RESOURCE: str
CONF_DOMAIN_DATA: str
CONF_CONNECTIONS: str
CONF_SK_NUM_TRIES: str
CONF_OUTPUT: str
CONF_DIM_MODE: str
CONF_DIMMABLE: str
CONF_TRANSITION: str
CONF_MOTOR: str
CONF_LOCKABLE: str
CONF_VARIABLE: str
CONF_VALUE: str
CONF_RELVARREF: str
CONF_SETPOINT: str
CONF_LED: str
CONF_KEYS: str
CONF_TIME: str
CONF_TIME_UNIT: str
CONF_TABLE: str
CONF_ROW: str
CONF_TEXT: str
CONF_PCK: str
CONF_CLIMATES: str
CONF_MAX_TEMP: str
CONF_MIN_TEMP: str
CONF_SCENES: str
CONF_REGISTER: str
CONF_OUTPUTS: str
CONF_REVERSE_TIME: str
DIM_MODES: Any
OUTPUT_PORTS: Any
RELAY_PORTS: Any
MOTOR_PORTS: Any
LED_PORTS: Any
LED_STATUS: Any
LOGICOP_PORTS: Any
BINSENSOR_PORTS: Any
KEYS: Any
VARIABLES: Any
SETPOINTS: Any
THRESHOLDS: Any
S0_INPUTS: Any
VAR_UNITS: Any
RELVARREF: Any
SENDKEYCOMMANDS: Any
TIME_UNITS: Any
MOTOR_REVERSE_TIME: Any
