DOMAIN: str
CONF_DEVICE_PASSWORD: str
CONF_PHONE_ID: str
DATA_BRIDGE: str
DATA_DEVICE: str
DATA_DISCOVERY: str
DISCOVERY_TIME_SEC: int
SIGNAL_DEVICE_ADD: str
CONF_AUTO_OFF: str
CONF_TIMER_MINUTES: str
SERVICE_SET_AUTO_OFF_NAME: str
SERVICE_TURN_ON_WITH_TIMER_NAME: str
MAX_UPDATE_INTERVAL_SEC: int
