from homeassistant.helpers import device_registry as dev_reg, entity_registry as ent_reg

class PermissionLookup:
    entity_registry: ent_reg.EntityRegistry
    device_registry: dev_reg.DeviceRegistry
    def __init__(self, entity_registry, device_registry) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...
