from . import DEVICE_CLASS_BATTERY as DEVICE_CLASS_BATTERY, DEVICE_CLASS_BATTERY_CHARGING as DEVICE_CLASS_BATTERY_CHARGING, DEVICE_CLASS_COLD as DEVICE_CLASS_COLD, DEVICE_CLASS_CONNECTIVITY as DEVICE_CLASS_CONNECTIVITY, DEVICE_CLASS_DOOR as DEVICE_CLASS_DOOR, DEVICE_CLASS_GARAGE_DOOR as DEVICE_CLASS_GARAGE_DOOR, DEVICE_CLASS_GAS as DEVICE_CLASS_GAS, DEVICE_CLASS_HEAT as DEVICE_CLASS_HEAT, DEVICE_CLASS_LIGHT as DEVICE_CLASS_LIGHT, DEVICE_CLASS_LOCK as DEVICE_CLASS_LOCK, DEVICE_CLASS_MOISTURE as DEVICE_CLASS_MOISTURE, DEVICE_CLASS_MOTION as DEVICE_CLASS_MOTION, DEVICE_CLASS_MOVING as DEVICE_CLASS_MOVING, DEVICE_CLASS_OCCUPANCY as DEVICE_CLASS_OCCUPANCY, DEVICE_CLASS_OPENING as DEVICE_CLASS_OPENING, DEVICE_CLASS_PLUG as DEVICE_CLASS_PLUG, DEVICE_CLASS_POWER as DEVICE_CLASS_POWER, DEVICE_CLASS_PRESENCE as DEVICE_CLASS_PRESENCE, DEVICE_CLASS_PROBLEM as DEVICE_CLASS_PROBLEM, DEVICE_CLASS_SAFETY as DEVICE_CLASS_SAFETY, DEVICE_CLASS_SMOKE as DEVICE_CLASS_SMOKE, DEVICE_CLASS_SOUND as DEVICE_CLASS_SOUND, DEVICE_CLASS_VIBRATION as DEVICE_CLASS_VIBRATION, DEVICE_CLASS_WINDOW as DEVICE_CLASS_WINDOW, DOMAIN as DOMAIN
from homeassistant.components.device_automation import DEVICE_TRIGGER_BASE_SCHEMA as DEVICE_TRIGGER_BASE_SCHEMA
from homeassistant.components.device_automation.const import CONF_TURNED_OFF as CONF_TURNED_OFF, CONF_TURNED_ON as CONF_TURNED_ON
from homeassistant.const import CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_FOR as CONF_FOR, CONF_TYPE as CONF_TYPE
from homeassistant.helpers.entity import get_device_class as get_device_class
from homeassistant.helpers.entity_registry import async_entries_for_device as async_entries_for_device
from typing import Any

DEVICE_CLASS_NONE: str
CONF_BAT_LOW: str
CONF_NOT_BAT_LOW: str
CONF_CHARGING: str
CONF_NOT_CHARGING: str
CONF_COLD: str
CONF_NOT_COLD: str
CONF_CONNECTED: str
CONF_NOT_CONNECTED: str
CONF_GAS: str
CONF_NO_GAS: str
CONF_HOT: str
CONF_NOT_HOT: str
CONF_LIGHT: str
CONF_NO_LIGHT: str
CONF_LOCKED: str
CONF_NOT_LOCKED: str
CONF_MOIST: str
CONF_NOT_MOIST: str
CONF_MOTION: str
CONF_NO_MOTION: str
CONF_MOVING: str
CONF_NOT_MOVING: str
CONF_OCCUPIED: str
CONF_NOT_OCCUPIED: str
CONF_PLUGGED_IN: str
CONF_NOT_PLUGGED_IN: str
CONF_POWERED: str
CONF_NOT_POWERED: str
CONF_PRESENT: str
CONF_NOT_PRESENT: str
CONF_PROBLEM: str
CONF_NO_PROBLEM: str
CONF_UNSAFE: str
CONF_NOT_UNSAFE: str
CONF_SMOKE: str
CONF_NO_SMOKE: str
CONF_SOUND: str
CONF_NO_SOUND: str
CONF_VIBRATION: str
CONF_NO_VIBRATION: str
CONF_OPENED: str
CONF_NOT_OPENED: str
TURNED_ON: Any
TURNED_OFF: Any
ENTITY_TRIGGERS: Any
TRIGGER_SCHEMA: Any

async def async_attach_trigger(hass, config, action, automation_info): ...
async def async_get_triggers(hass, device_id): ...
async def async_get_trigger_capabilities(hass, config): ...
