from typing import Final

CONF_BUFFER_SIZE: Final[str]
CONF_VALUE_ON: Final[str]
DEFAULT_BUFFER_SIZE: Final[int]
DEFAULT_NAME: Final[str]
DEFAULT_TIMEOUT: Final[int]
DEFAULT_SSL: Final[bool]
DEFAULT_VERIFY_SSL: Final[bool]
