from ipaddress import IPv4Address, IPv6Address
from typing import Any

LOOPBACK_NETWORKS: Any
PRIVATE_NETWORKS: Any
LINK_LOCAL_NETWORK: Any

def is_loopback(address: Union[IPv4Address, IPv6Address]) -> bool: ...
def is_private(address: Union[IPv4Address, IPv6Address]) -> bool: ...
def is_link_local(address: Union[IPv4Address, IPv6Address]) -> bool: ...
def is_local(address: Union[IPv4Address, IPv6Address]) -> bool: ...
def is_invalid(address: Union[IPv4Address, IPv6Address]) -> bool: ...
def is_ip_address(address: str) -> bool: ...
def normalize_url(address: str) -> str: ...
