from homeassistant import runner as runner
from homeassistant.auth import auth_manager_from_config as auth_manager_from_config
from homeassistant.config import get_default_config_dir as get_default_config_dir
from homeassistant.core import HomeAssistant as HomeAssistant

def run(args) -> None: ...
async def run_command(args) -> None: ...
async def list_users(hass, provider, args) -> None: ...
async def add_user(hass, provider, args) -> None: ...
async def validate_login(hass, provider, args) -> None: ...
async def change_password(hass, provider, args) -> None: ...
