from .const import BINSENSOR_PORTS as BINSENSOR_PORTS, CONF_CLIMATES as CONF_CLIMATES, CONF_CONNECTIONS as CONF_CONNECTIONS, CONF_DIMMABLE as CONF_DIMMABLE, CONF_DIM_MODE as CONF_DIM_MODE, CONF_LOCKABLE as CONF_LOCKABLE, CONF_MAX_TEMP as CONF_MAX_TEMP, CONF_MIN_TEMP as CONF_MIN_TEMP, CONF_MOTOR as CONF_MOTOR, CONF_OUTPUT as CONF_OUTPUT, CONF_OUTPUTS as CONF_OUTPUTS, CONF_REGISTER as CONF_REGISTER, CONF_REVERSE_TIME as CONF_REVERSE_TIME, CONF_SCENES as CONF_SCENES, CONF_SETPOINT as CONF_SETPOINT, CONF_SK_NUM_TRIES as CONF_SK_NUM_TRIES, CONF_TRANSITION as CONF_TRANSITION, DIM_MODES as DIM_MODES, DOMAIN as DOMAIN, KEYS as KEYS, LED_PORTS as LED_PORTS, LOGICOP_PORTS as LOGICOP_PORTS, MOTOR_PORTS as MOTOR_PORTS, MOTOR_REVERSE_TIME as MOTOR_REVERSE_TIME, OUTPUT_PORTS as OUTPUT_PORTS, RELAY_PORTS as RELAY_PORTS, S0_INPUTS as S0_INPUTS, SETPOINTS as SETPOINTS, TEMP_CELSIUS as TEMP_CELSIUS, TEMP_FAHRENHEIT as TEMP_FAHRENHEIT, THRESHOLDS as THRESHOLDS, VARIABLES as VARIABLES, VAR_UNITS as VAR_UNITS
from .helpers import has_unique_host_names as has_unique_host_names, is_address as is_address
from homeassistant.components.climate import DEFAULT_MAX_TEMP as DEFAULT_MAX_TEMP, DEFAULT_MIN_TEMP as DEFAULT_MIN_TEMP
from homeassistant.const import CONF_ADDRESS as CONF_ADDRESS, CONF_BINARY_SENSORS as CONF_BINARY_SENSORS, CONF_COVERS as CONF_COVERS, CONF_HOST as CONF_HOST, CONF_LIGHTS as CONF_LIGHTS, CONF_NAME as CONF_NAME, CONF_PASSWORD as CONF_PASSWORD, CONF_PORT as CONF_PORT, CONF_SCENE as CONF_SCENE, CONF_SENSORS as CONF_SENSORS, CONF_SOURCE as CONF_SOURCE, CONF_SWITCHES as CONF_SWITCHES, CONF_UNIT_OF_MEASUREMENT as CONF_UNIT_OF_MEASUREMENT, CONF_USERNAME as CONF_USERNAME
from typing import Any

DOMAIN_DATA_BINARY_SENSOR: Any
DOMAIN_DATA_CLIMATE: Any
DOMAIN_DATA_COVER: Any
DOMAIN_DATA_LIGHT: Any
DOMAIN_DATA_SCENE: Any
DOMAIN_DATA_SENSOR: Any
DOMAIN_DATA_SWITCH: Any
DOMAIN_DATA_BASE: Any
BINARY_SENSORS_SCHEMA: Any
CLIMATES_SCHEMA: Any
COVERS_SCHEMA: Any
LIGHTS_SCHEMA: Any
SCENES_SCHEMA: Any
SENSORS_SCHEMA: Any
SWITCHES_SCHEMA: Any
CONNECTION_SCHEMA: Any
CONFIG_SCHEMA: Any
