from typing import Any, Final

COAP: Final[str]
DATA_CONFIG_ENTRY: Final[str]
DEVICE: Final[str]
DOMAIN: Final[str]
REST: Final[str]
CONF_COAP_PORT: Final[str]
DEFAULT_COAP_PORT: Final[int]
POLLING_TIMEOUT_SEC: Final[int]
REST_SENSORS_UPDATE_INTERVAL: Final[int]
AIOSHELLY_DEVICE_TIMEOUT_SEC: Final[int]
SLEEP_PERIOD_MULTIPLIER: Final[float]
UPDATE_PERIOD_MULTIPLIER: Final[float]
SHAIR_MAX_WORK_HOURS: Final[int]
INPUTS_EVENTS_DICT: Final[Any]
BATTERY_DEVICES_WITH_PERMANENT_CONNECTION: Final[Any]
EVENT_SHELLY_CLICK: Final[str]
ATTR_CLICK_TYPE: Final[str]
ATTR_CHANNEL: Final[str]
ATTR_DEVICE: Final[str]
CONF_SUBTYPE: Final[str]
BASIC_INPUTS_EVENTS_TYPES: Final[Any]
SHBTN_INPUTS_EVENTS_TYPES: Final[Any]
SUPPORTED_INPUTS_EVENTS_TYPES: Final[Any]
SHIX3_1_INPUTS_EVENTS_TYPES = SUPPORTED_INPUTS_EVENTS_TYPES
INPUTS_EVENTS_SUBTYPES: Final[Any]
SHBTN_MODELS: Final[Any]
STANDARD_RGB_EFFECTS: Final[Any]
SHBLB_1_RGB_EFFECTS: Final[Any]
KELVIN_MAX_VALUE: Final[int]
KELVIN_MIN_VALUE_WHITE: Final[int]
KELVIN_MIN_VALUE_COLOR: Final[int]
UPTIME_DEVIATION: Final[int]
LAST_RESET_UPTIME: Final[str]
LAST_RESET_NEVER: Final[str]
