from typing import Any, Final

LOGGER: Final[Any]
DOMAIN: Final[str]
PLATFORM_TYPE_LEGACY: Final[str]
PLATFORM_TYPE_ENTITY: Final[str]
SOURCE_TYPE_GPS: Final[str]
SOURCE_TYPE_ROUTER: Final[str]
SOURCE_TYPE_BLUETOOTH: Final[str]
SOURCE_TYPE_BLUETOOTH_LE: Final[str]
CONF_SCAN_INTERVAL: Final[str]
SCAN_INTERVAL: Final[Any]
CONF_TRACK_NEW: Final[str]
DEFAULT_TRACK_NEW: Final[bool]
CONF_CONSIDER_HOME: Final[str]
DEFAULT_CONSIDER_HOME: Final[Any]
CONF_NEW_DEVICE_DEFAULTS: Final[str]
ATTR_ATTRIBUTES: Final[str]
ATTR_BATTERY: Final[str]
ATTR_DEV_ID: Final[str]
ATTR_GPS: Final[str]
ATTR_HOST_NAME: Final[str]
ATTR_LOCATION_NAME: Final[str]
ATTR_MAC: Final[str]
ATTR_SOURCE_TYPE: Final[str]
ATTR_CONSIDER_HOME: Final[str]
ATTR_IP: Final[str]
