from typing import Any

DOMAIN: str
LOGGER: Any
API_SENSOR_PAIRED_SENSOR_STATUS: str
API_SENSOR_PAIR_DUMP: str
API_SYSTEM_DIAGNOSTICS: str
API_SYSTEM_ONBOARD_SENSOR_STATUS: str
API_VALVE_STATUS: str
API_WIFI_STATUS: str
CONF_UID: str
DATA_CLIENT: str
DATA_COORDINATOR: str
DATA_COORDINATOR_PAIRED_SENSOR: str
DATA_PAIRED_SENSOR_MANAGER: str
DATA_UNSUB_DISPATCHER_CONNECT: str
SIGNAL_PAIRED_SENSOR_COORDINATOR_ADDED: str
