import logging
from typing import Final

ATTR_STATE_BATTERY_LOW: Final[str]
ATTR_STATE_DEVICE_LOCKED: Final[str]
ATTR_STATE_HOLIDAY_MODE: Final[str]
ATTR_STATE_LOCKED: Final[str]
ATTR_STATE_SUMMER_MODE: Final[str]
ATTR_STATE_WINDOW_OPEN: Final[str]
ATTR_TEMPERATURE_UNIT: Final[str]
CONF_CONNECTIONS: Final[str]
CONF_COORDINATOR: Final[str]
DEFAULT_HOST: Final[str]
DEFAULT_USERNAME: Final[str]
DOMAIN: Final[str]
LOGGER: Final[logging.Logger]
PLATFORMS: Final[list[str]]
