from typing import Any

DOMAIN: str
ATTR_UNIQUE_ID: str
CONF_TRACK_WIRED_CLIENTS: str
CONF_UNAUTHENTICATED_MODE: str
DEFAULT_DEVICE_NAME: str
DEFAULT_NOTIFY_SERVICE_NAME = DOMAIN
DEFAULT_TRACK_WIRED_CLIENTS: bool
DEFAULT_UNAUTHENTICATED_MODE: bool
UPDATE_SIGNAL: Any
CONNECTION_TIMEOUT: int
NOTIFY_SUPPRESS_TIMEOUT: int
SERVICE_CLEAR_TRAFFIC_STATISTICS: str
SERVICE_REBOOT: str
SERVICE_RESUME_INTEGRATION: str
SERVICE_SUSPEND_INTEGRATION: str
ADMIN_SERVICES: Any
KEY_DEVICE_BASIC_INFORMATION: str
KEY_DEVICE_INFORMATION: str
KEY_DEVICE_SIGNAL: str
KEY_DIALUP_MOBILE_DATASWITCH: str
KEY_LAN_HOST_INFO: str
KEY_MONITORING_CHECK_NOTIFICATIONS: str
KEY_MONITORING_MONTH_STATISTICS: str
KEY_MONITORING_STATUS: str
KEY_MONITORING_TRAFFIC_STATISTICS: str
KEY_NET_CURRENT_PLMN: str
KEY_NET_NET_MODE: str
KEY_SMS_SMS_COUNT: str
KEY_WLAN_HOST_LIST: str
KEY_WLAN_WIFI_FEATURE_SWITCH: str
BINARY_SENSOR_KEYS: Any
DEVICE_TRACKER_KEYS: Any
SENSOR_KEYS: Any
SWITCH_KEYS: Any
ALL_KEYS: Any
